package cn.com.infosec.asn1.cms;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;

public class RecipientEncryptedKey extends ASN1Encodable {
   private KeyAgreeRecipientIdentifier identifier;
   private ASN1OctetString encryptedKey;

   private RecipientEncryptedKey(ASN1Sequence seq) {
      this.identifier = KeyAgreeRecipientIdentifier.getInstance(seq.getObjectAt(0));
      this.encryptedKey = (ASN1OctetString)seq.getObjectAt(1);
   }

   public static RecipientEncryptedKey getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static RecipientEncryptedKey getInstance(Object obj) {
      if (obj != null && !(obj instanceof RecipientEncryptedKey)) {
         if (obj instanceof ASN1Sequence) {
            return new RecipientEncryptedKey((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("Invalid RecipientEncryptedKey: " + obj.getClass().getName());
         }
      } else {
         return (RecipientEncryptedKey)obj;
      }
   }

   public RecipientEncryptedKey(KeyAgreeRecipientIdentifier id, ASN1OctetString encryptedKey) {
      this.identifier = id;
      this.encryptedKey = encryptedKey;
   }

   public KeyAgreeRecipientIdentifier getIdentifier() {
      return this.identifier;
   }

   public ASN1OctetString getEncryptedKey() {
      return this.encryptedKey;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.identifier);
      var10000.add(this.encryptedKey);
      return new DERSequence(var1);
   }
}
